==> donorperfect-1.0.1.tar.gz: donorperfect/src/Controller/DonorPerfectController.php <==
<?php

namespace Drupal\donorperfect\Controller;

use Drupal\Component\Serialization\Json;
use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\HtmlCommand;
use Drupal\Core\Ajax\InvokeCommand;
use Drupal\Core\Ajax\RedirectCommand;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Render\Markup;
use Drupal\Core\Url;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Drupal\donorperfect\DPQuery;
use Drupal\donorperfect\DPUtility;

/**
 * Provides miscellaneous page callbacks for the DonorPerfect module.
 */
class DonorPerfectController extends ControllerBase {

  /**
   * Page callback to refresh the DonorPerfect cache.
   *
   * @param mixed $ajax
   *   Indicates whether this was called by ajax.
   */
  public function refreshCache(mixed $ajax=FALSE) {
    $query = new DPQuery();
    $query->refreshCache();
    $this->messenger()->addStatus($this->t('DonorPerfect cache refreshed successfully.'));
    $redirect_url = Url::fromUserInput($this->getRedirectDestination()->get())->setAbsolute()->toString();
    if ($ajax === 'ajax') {
      $response = new AjaxResponse();
      $response->addCommand(new RedirectCommand($redirect_url));
      return $response;
    } else {
      return new RedirectResponse($redirect_url);
    }
  }

  /**
   * Page callback for the name form_element to search donors by name.
   *
   * @return \Drupal\Core\Ajax\AjaxResponse
   */
  public function searchDonors() {
    $response = new AjaxResponse();
    $request_values = ['element_token' => ''];
    $donors = [];
    $result_content = '<strong>No matches found.</strong>';
    if ($this->moduleHandler()->moduleExists('donorperfect_donor')) {
      $request = \Drupal::request();
      foreach (['element_token', 'donor_type', 'last_name', 'first_name'] as $request_key) {
        $request_values[$request_key] = $request->get($request_key);
      }
      if (!empty($request_values['last_name'])) {
        $search_conditions = [];
        $search_conditions[] = ['table' => 'dp', 'field' => 'last_name', 'value' => $request_values['last_name'], 'wildcard' => 'after'];
        if (!empty($request_values['donor_type']) && ($request_values['donor_type'] === 'IN')) {
          $search_conditions[] = ['table' => 'dp', 'field' => 'donor_type', 'value' => $request_values['donor_type']];
          if (!empty($request_values['first_name'])) {
            $search_conditions[] = ['table' => 'dp', 'field' => 'first_name', 'value' => $request_values['first_name'], 'wildcard' => 'both'];
          }
        }
        $search_results = \Drupal\donorperfect_donor\Entity\DonorController::search($search_conditions);
        if (!empty($search_results)) {
          $donors = DPUtility::entityLoadMultiple('donorperfect_donor', $search_results);
        }
      }
    }
    if (!empty($donors)) {
      $result_content = [];
      $result_content[] = ['#markup' => Markup::create('<h3>Possible Matches in DonorPerfect</h3>')];
      $caption = (count($donors) == 1) ? '1 possible match' : count($donors) . ' possible matches';
      $header = [
        ['data' => $this->t('Match'), 'class' => ['donorperfect-name-search-match-link']],
        ['data' => $this->t('Name')],
        ['data' => $this->t('Address')],
        ['data' => $this->t('City')],
        ['data' => $this->t('State')],
        ['data' => $this->t('Zip')],
        ['data' => $this->t('Email')],
      ];
      $rows = [];
      foreach ($donors as $donor_id => $donor) {
        $donor_data = [];
        foreach (['donor_id', 'donor_type', 'first_name', 'last_name', 'address', 'city', 'state', 'zip', 'email', 'mobile_phone', 'home_phone', 'business_phone', 'fax_phone'] as $field_key) {
          $donor_data[$field_key] = $donor->getFieldValue($field_key);
        }
        $row = [];
        $row[] = ['data' => Markup::create('<a href="#" result-data=' . str_replace(' ', '&nbsp;', Json::encode($donor_data)) . '>' . $this->t('Match') . '</a>'), 'class' => ['donorperfect-name-search-match-link']];
        $row[] = ['data' => trim($donor_data['first_name'] . ' ' . $donor_data['last_name'])];
        $row[] = ['data' => $donor_data['address']];
        $row[] = ['data' => $donor_data['city']];
        $row[] = ['data' => $donor_data['state']];
        $row[] = ['data' => $donor_data['zip']];
        $row[] = ['data' => $donor_data['email']];
        $rows[] = $row;
      }
      $attributes = ['class' => ['donorperfect-name-search-results-table']];
      $result_content[] = [
        '#theme' => 'table',
        '#caption' => $caption,
        '#attributes' => $attributes,
        '#header' => $header,
        '#rows' => $rows,
      ];
    }
    $response->addCommand(new HtmlCommand('div#donorperfect-name-search-wrapper-' . $request_values['element_token'] . ' > div.donorperfect-name-search-results', $result_content));
    $invoke_args = ['show' => 'results', 'element_token' => $request_values['element_token']];
    $response->addCommand(new InvokeCommand(NULL, 'DonorPerfectFormElementNameSearchSwitchLoadingResults', [Json::encode($invoke_args)]));
    return $response;
  }

}

==> donorperfect-1.0.6.tar.gz: donorperfect/src/Controller/DonorPerfectController.php <==
<?php

namespace Drupal\donorperfect\Controller;

use Drupal\Component\Serialization\Json;
use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\HtmlCommand;
use Drupal\Core\Ajax\InvokeCommand;
use Drupal\Core\Ajax\RedirectCommand;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Render\Markup;
use Drupal\Core\Url;
use Drupal\donorperfect\DPQuery;
use Drupal\donorperfect\DPUtility;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 * Provides miscellaneous page callbacks for the DonorPerfect module.
 */
class DonorPerfectController extends ControllerBase {

  /**
   * Page callback to refresh the DonorPerfect cache.
   *
   * @param mixed $ajax
   *   Indicates whether this was called by ajax.
   */
  public function refreshCache(mixed $ajax = FALSE) {
    $query = new DPQuery();
    $query->refreshCache();
    $this->messenger()->addStatus($this->t('DonorPerfect cache refreshed successfully.'));
    $redirect_url = Url::fromUserInput($this->getRedirectDestination()->get())->setAbsolute()->toString();
    if ($ajax === 'ajax') {
      $response = new AjaxResponse();
      $response->addCommand(new RedirectCommand($redirect_url));
      return $response;
    }
    else {
      return new RedirectResponse($redirect_url);
    }
  }

  /**
   * Page callback for the name form_element to search donors by name.
   *
   * @return \Drupal\Core\Ajax\AjaxResponse
   *   The ajax response.
   */
  public function searchDonors() {
    $response = new AjaxResponse();
    $request_values = ['element_token' => ''];
    $donors = [];
    $result_content = '<strong>No matches found.</strong>';
    if ($this->moduleHandler()->moduleExists('donorperfect_donor')) {
      $request = \Drupal::request();
      foreach (['element_token', 'donor_type', 'last_name', 'first_name'] as $request_key) {
        $request_values[$request_key] = $request->get($request_key);
      }
      if (!empty($request_values['last_name'])) {
        $search_conditions = [];
        $search_conditions[] = [
          'table' => 'dp',
          'field' => 'last_name',
          'value' => $request_values['last_name'],
          'wildcard' => 'after',
        ];
        if (!empty($request_values['donor_type']) && ($request_values['donor_type'] === 'IN')) {
          $search_conditions[] = [
            'table' => 'dp',
            'field' => 'donor_type',
            'value' => $request_values['donor_type'],
          ];
          if (!empty($request_values['first_name'])) {
            $search_conditions[] = [
              'table' => 'dp',
              'field' => 'first_name',
              'value' => $request_values['first_name'],
              'wildcard' => 'both',
            ];
          }
        }
        // No 'use' statement for this class because it's only being called
        // if the donorperfect_donor module is enabled.
        $search_results = \Drupal\donorperfect_donor\Entity\DonorController::search($search_conditions);
        if (!empty($search_results)) {
          $donors = DPUtility::entityLoadMultiple('donorperfect_donor', $search_results);
        }
      }
    }
    if (!empty($donors)) {
      $result_content = [];
      $result_content[] = ['#markup' => Markup::create('<h3>Possible Matches in DonorPerfect</h3>')];
      $caption = (count($donors) == 1) ? '1 possible match' : count($donors) . ' possible matches';
      $header = [
        ['data' => $this->t('Match'), 'class' => ['donorperfect-name-search-match-link']],
        ['data' => $this->t('Name')],
        ['data' => $this->t('Address')],
        ['data' => $this->t('City')],
        ['data' => $this->t('State')],
        ['data' => $this->t('Zip')],
        ['data' => $this->t('Email')],
      ];
      $rows = [];
      foreach ($donors as $donor) {
        $donor_data = [];
        $field_keys = [
          'donor_id',
          'donor_type',
          'first_name',
          'last_name',
          'address',
          'city',
          'state',
          'zip',
          'email',
          'mobile_phone',
          'home_phone',
          'business_phone',
          'fax_phone',
        ];
        foreach ($field_keys as $field_key) {
          $donor_data[$field_key] = $donor->getFieldValue($field_key);
        }
        $row = [];
        $match_link = Markup::create('<a href="#" result-data=' . str_replace(' ', '&nbsp;', Json::encode($donor_data)) . '>' . $this->t('Match') . '</a>');
        $row[] = ['data' => $match_link, 'class' => ['donorperfect-name-search-match-link']];
        $row[] = ['data' => trim($donor_data['first_name'] . ' ' . $donor_data['last_name'])];
        $row[] = ['data' => $donor_data['address']];
        $row[] = ['data' => $donor_data['city']];
        $row[] = ['data' => $donor_data['state']];
        $row[] = ['data' => $donor_data['zip']];
        $row[] = ['data' => $donor_data['email']];
        $rows[] = $row;
      }
      $attributes = ['class' => ['donorperfect-name-search-results-table']];
      $result_content[] = [
        '#theme' => 'table',
        '#caption' => $caption,
        '#attributes' => $attributes,
        '#header' => $header,
        '#rows' => $rows,
      ];
    }
    $response->addCommand(new HtmlCommand('div#donorperfect-name-search-wrapper-' . $request_values['element_token'] . ' > div.donorperfect-name-search-results', $result_content));
    $invoke_args = ['show' => 'results', 'element_token' => $request_values['element_token']];
    $response->addCommand(new InvokeCommand(NULL, 'DonorPerfectFormElementNameSearchSwitchLoadingResults', [Json::encode($invoke_args)]));
    return $response;
  }

}
